@@ -14,7 +14,7 @@ use Plack::Util;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.2';
+our $VERSION = 'v0.1.3';
 
 
 sub serve_static_file {
@@ -24,10 +24,6 @@ sub serve_static_file {
 
     my $abs = File::Spec->rel2abs( "$path" );
 
-    unless ( -e $abs ) {
-        Catalyst::Exception->throw( "File ${abs} was not found" );
-    }
-
     my $fh = IO::File->new( $abs, "r" );
     if ( defined $fh ) {
         binmode($fh);
@@ -39,13 +35,13 @@ sub serve_static_file {
         my $headers = $res->headers;
         $headers->content_type("$type");
 
-        my $stat = stat($abs);
+        my $stat = stat($fh);
         $headers->content_length( $stat->size );
         $headers->last_modified( $stat->mtime );
 
     }
     else {
-        Catalyst::Exception->throw( "Unable to open $path for reading" );
+        Catalyst::Exception->throw( "Unable to open ${abs} for reading: $!" );
     }
 
     return 1;
@@ -66,7 +62,7 @@ Catalyst::Plugin::Static::File - Serve a specific static file
 
 =head1 VERSION
 
-version v0.1.2
+version v0.1.3
 
 =head1 SYNOPSIS
 
